package fileChooser;

import java.io.*;

/**
 *
 * @author tadaki
 */
public class FileUtil {

    /**
     * fileの内容をObjectとして返す
     * @param file 読み込むfile
     * @return fileから読み込まれたObject
     */
    static public Object openFile(File file)
            throws IOException, FileNotFoundException, ClassNotFoundException {
        if (!file.canRead()) {//ファイルが読めることを確認
            String message = file.getName() + " は読めません";
            throw new IOException(message);
        }
        //読み出し開始
        ObjectInputStream in = null;
        Object o = null;
        in = new ObjectInputStream(new FileInputStream(file));
        o = in.readObject();
        return o;
    }

    static public graphLib.Network openXML(File file) throws IOException {
        if (!file.canRead()) {//ファイルが読めることを確認
            String message = file.getName() + " は読めません";
            throw new IOException(message);
        }
        NetworkData nData = new NetworkData();
        return nData.input(file);
    }

    /**
     * Objectをfileに保存する。
     * @param file　保存先file
     * @param 保存するObject
     */
    static public void saveFile(File file, Object object)
            throws IOException, FileNotFoundException {
        //保存開始
        ObjectOutputStream out;
        out = new ObjectOutputStream(new FileOutputStream(file));
        out.writeObject(object);
    }

    static public void saveXML(File file, graphLib.Network network)
            throws IOException {
        NetworkData nData = new NetworkData();
        nData.output(network, file.getName(), file.getPath());
    }

    /**
     * file への書き込み可能性を確認
     * @param file
     * @return 書き込み可能ならばtrue
     */
    static public boolean checkWritable(File file) throws IOException {
        if (file.isFile()) {//ファイルが存在する場合
            if (!file.canWrite()) {//上書き可能性の確認
                String message = file.getName() + " に書き込めません";
                throw new IOException(message);
            }
        }
        return true;
    }

    /**
     * file を読める可能性を確認
     * @param file
     * @return 読み込み可能ならばtrue
     */
    static public boolean checkReadable(File file) throws IOException {
        if(file.isFile()){
            if(!file.canRead()){
                String message = file.getName() + " を読めません";
                throw new IOException(message);               
            }
        }
        return true;
    }
    /**
     * ファイル名中の拡張子を調べる
     * @param filename
     * @return 拡張子の文字列
     */
    static public String getExtention(String filename) {
        String ext = null;
        int index = filename.lastIndexOf(".");
        if (index > 0) {
            ext = filename.substring(index + 1);
            if (ext.length() < 1) {
                ext = null;
            }
        }
        return ext;
    }
    
    static public OutputStreamWriter openOutputStream(String filename) 
            throws FileNotFoundException{
        File file = new File(filename);
        return new OutputStreamWriter(new FileOutputStream(file));
    }
    
    static public InputStreamReader openInputStream(File file) 
            throws FileNotFoundException{
        return new InputStreamReader(new FileInputStream(file));
    }
}
