package graphLib;

/**
 * 弧のクラス
 * @author tadaki
 */
public class Arc implements java.io.Serializable {

    private String name;
    /** 弧の重み */
    private double weight;
    private boolean nameWithWeight = false;
    /** 弧を流れる流量 */
    private double flow;
    private boolean nameWithFlow = false;

    /**
     * Creates a new instance of Arc
     * @param name 弧のラベル
     */
    public Arc(String name) {
        this.name = name;
    }

    /**
     * コピーコンストラクタ
     * @param a 元の弧
     */
    public Arc(final Arc a) {
        this.name = a.name;
        this.weight = a.weight;
        this.nameWithWeight = a.nameWithWeight;
        this.nameWithFlow = a.nameWithFlow;
        this.flow = a.flow;
    }

    /**
     * 弧のラベルを返す
     * @return 弧のラベル
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(getName());
        if (isNameWithWeight()) {
            sb.append("(");
            if (isNameWithFlow()) {
                sb.append(String.valueOf(getFlow())).append("/");
            }
            sb.append(String.valueOf(getWeight()));
            sb.append(")");
        }
        return sb.toString();
    }

    /** 設定及び取得メソッド ********************************************/
    /**
     * 弧の重みを取得
     * @return 弧の重み
     */
    public double getWeight() {
        return weight;
    }

    /**
     * 弧に重みを設定
     * @param weight 設定する重み
     */
    public void setWeight(double weight) {
        this.weight = weight;
    }

    /**
     * 弧のフローを取得
     * @return  取得したフロー
     */
    public double getFlow() {
        return flow;
    }

    /**
     * 弧にフローを設定
     * @param flow 設定するフロー
     */
    public void setFlow(double flow) {
        this.flow = flow;
    }

    /**
     * 弧の名前を表示する際に重みも表示するか
     * @return 真ならば、重みも表示
     */
    public boolean isNameWithWeight() {
        return nameWithWeight;
    }

    /**
     * 弧の名前を表示する際に重みも表示するか
     * @param nameWithWeight 真ならば、重みも表示
     */
    public void setNameWithWeight(boolean nameWithWeight) {
        this.nameWithWeight = nameWithWeight;
    }

    /**
     * 弧の名前を表示する際にフローも表示するか
     * @return 真ならば、フローも表示
     */
    public boolean isNameWithFlow() {
        return nameWithFlow;
    }

    /**
     * 弧の名前を表示する際にフローも表示するか
     * @param nameWithFlow 真ならば、フローも表示
     */
    public void setNameWithFlow(boolean nameWithFlow) {
        this.nameWithFlow = nameWithFlow;
    }

    /**
     * 弧の名前を取得
     * @return 取得した名前
     */
    public String getName() {
        return name;
    }

    /**
     * 弧の名前を設定
     * @param name
     */
    public void setName(String name) {
        this.name = name;
    }
}
